@@ -353,9 +353,9 @@ cached_dir_update_entry (CachedDir  *dir,
       if (strcmp (desktop_entry_get_basename (tmp->data), basename) == 0)
         {
           if (!desktop_entry_reload (tmp->data))
-	    {
-	      dir->entries = g_slist_delete_link (dir->entries, tmp);
-	    }
+            {
+              dir->entries = g_slist_delete_link (dir->entries, tmp);
+            }
 
           return TRUE;
         }
@@ -520,10 +520,12 @@ cached_dir_queue_monitor_event (CachedDir *dir)
       cached_dir_queue_monitor_event (dir->parent);
     }
 
-  if (monitors_idle_handler == 0)
+  if (monitors_idle_handler > 0)
     {
-      monitors_idle_handler = g_idle_add ((GSourceFunc) emit_monitors_in_idle, NULL);
+      g_source_remove (monitors_idle_handler);
     }
+
+    monitors_idle_handler = g_timeout_add (100, (GSourceFunc) emit_monitors_in_idle, NULL);
 }
 
 static void
